@@ -3,8 +3,10 @@ package org.jmx4perl;
 
 import org.jmx4perl.config.Config;
 import org.jmx4perl.config.DebugStore;
+import org.jmx4perl.config.Restrictor;
+import org.jmx4perl.config.RestrictorFactory;
 import org.jmx4perl.converter.StringToObjectConverter;
-import org.jmx4perl.converter.attribute.ObjectToJsonConverter;
+import org.jmx4perl.converter.json.ObjectToJsonConverter;
 import org.jmx4perl.handler.*;
 import org.jmx4perl.history.HistoryStore;
 import org.json.simple.JSONObject;
@@ -60,7 +62,7 @@ import java.util.Map;
  * like strings or numbers, collections, arrays and maps are also supported (which
  * translate into the corresponding JSON structure). Additional the OpenMBean types
  * {@link javax.management.openmbean.CompositeData} and {@link javax.management.openmbean.TabularData}
- * are supported as well. Refer to {@link org.jmx4perl.converter.attribute.ObjectToJsonConverter}
+ * are supported as well. Refer to {@link org.jmx4perl.converter.json.ObjectToJsonConverter}
  * for additional information.
  *
  * For the client part, please read the documentation of
@@ -96,8 +98,8 @@ public class AgentServlet extends HttpServlet {
     private ObjectName configMBeanName;
 
     @Override
-    public void init() throws ServletException {
-        super.init();
+    public void init(ServletConfig pConfig) throws ServletException {
+        super.init(pConfig);
 
         // Get all MBean servers we can find. This is done by a dedicated
         // handler object
@@ -108,7 +110,7 @@ public class AgentServlet extends HttpServlet {
 
         // Central objects
         stringToObjectConverter = new StringToObjectConverter();
-        objectToJsonConverter = new ObjectToJsonConverter(stringToObjectConverter);
+        objectToJsonConverter = new ObjectToJsonConverter(stringToObjectConverter,pConfig);
 
         registerRequestHandler();
         registerOwnMBeans();
@@ -139,7 +141,7 @@ public class AgentServlet extends HttpServlet {
         int code = 200;
         Throwable throwable = null;
         try {
-            jmxReq = new JmxRequest(pReq.getPathInfo());
+            jmxReq = new JmxRequest(pReq.getPathInfo(),pReq.getParameterMap());
             boolean debug = isDebug() && !"debugInfo".equals(jmxReq.getOperation());
             if (debug) {
                 log("URI: " + pReq.getRequestURI());
@@ -170,6 +172,10 @@ public class AgentServlet extends HttpServlet {
         } catch (IllegalStateException exp) {
             code = 500;
             throwable = exp;
+        } catch (SecurityException exception) {
+            code = 403;
+            // Wipe out stacktrace
+            throwable = new Exception(exception.getMessage());
         } catch (Exception exp) {
             code = 500;
             throwable = exp;
@@ -226,13 +232,16 @@ public class AgentServlet extends HttpServlet {
 
 
     private void registerRequestHandler() {
+
+        Restrictor restrictor = RestrictorFactory.buildRestrictor();
+
         RequestHandler handlers[] = {
-                new ReadHandler(),
-                new WriteHandler(objectToJsonConverter),
-                new ExecHandler(stringToObjectConverter),
-                new ListHandler(),
-                new VersionHandler(),
-                new SearchHandler()
+                new ReadHandler(restrictor),
+                new WriteHandler(restrictor,objectToJsonConverter),
+                new ExecHandler(restrictor,stringToObjectConverter),
+                new ListHandler(restrictor),
+                new VersionHandler(restrictor),
+                new SearchHandler(restrictor)
         };
 
         requestHandlerMap = new HashMap<JmxRequest.Type,RequestHandler>();
@@ -296,6 +305,8 @@ public class AgentServlet extends HttpServlet {
             } catch (MBeanRegistrationException e) {
                 log("Cannot unregister MBean: " + e,e);
             }
+        } else {
+            log("Internal Problem: No ConfigMBean name !");
         }
     }
 
